@@ -95,6 +95,8 @@ Application to convert a bliss-hdf5 tomography dataset to Nexus - NXtomo (hdf5)
       --config CONFIG, --config-file CONFIG, --configuration CONFIG, --configuration-file CONFIG
                             file containing the full configuration to convert from h5 bliss to nexus
 
+For a complete tutorial you can have a look at: :ref:`Tomoh52nx`
+
 """
 
 __authors__ = ["C. Nemoz", "H. Payno", "A.Sole"]
@@ -105,8 +107,8 @@ import logging
 from nxtomomill import utils
 from nxtomomill.utils import Progress
 from nxtomomill.converter import from_h5_to_nx
-from nxtomomill.io.confighandler import TomoHDF5ConfigHandler
-from nxtomomill.io.confighandler import SETTABLE_PARAMETERS_UNITS
+from nxtomomill.io.config.confighandler import TomoHDF5ConfigHandler
+from nxtomomill.io.config.confighandler import SETTABLE_PARAMETERS_UNITS
 from nxtomomill.utils import Format
 from collections.abc import Iterable
 import argparse
@@ -371,8 +373,7 @@ def main(argv):
                     options.format
                 )
             except ValueError:
-                _logger.error("Invalid format provided: {}".format(options.format))
-                exit(1)
+                raise RuntimeError("Invalid format provided: {}".format(options.format))
         for title in configuration_handler.configuration.init_titles:
             assert title != ""
         logging.getLogger("nxtomomill").setLevel(
@@ -384,9 +385,3 @@ def main(argv):
             input_callback=None,
             detector_sel_callback=callback_det_sel,
         )
-
-
-if __name__ == "__main__":
-    import sys
-
-    main(sys.argv[1:])
