@@ -103,8 +103,8 @@ import logging
 from nxtomomill import utils
 from nxtomomill.utils import Progress
 from nxtomomill.converter import from_h5_to_nx
-from nxtomomill.io.confighandler import XRD3DHDF5ConfigHandler
-from nxtomomill.io.confighandler import SETTABLE_PARAMETERS_UNITS
+from nxtomomill.io.config.confighandler import XRD3DHDF5ConfigHandler
+from nxtomomill.io.config.confighandler import SETTABLE_PARAMETERS_UNITS
 from collections.abc import Iterable
 from nxtomomill.utils import Format
 from nxtomomill.io.config import XRD3DHDF5Config
@@ -377,9 +377,3 @@ def main(argv):
             detector_sel_callback=callback_det_sel,
         )
     exit(0)
-
-
-if __name__ == "__main__":
-    import sys
-
-    main(sys.argv[1:])
