@@ -62,7 +62,7 @@ _logger = logging.getLogger(__name__)
 
 
 def _ask_for_file_removal(file_path):
-    res = input("Overwrite %s ? (Y/n)" % file_path)
+    res = input(f"Overwrite {file_path} ? (Y/n)")
     return res == "Y"
 
 
@@ -76,33 +76,37 @@ class BaseAcquisition:
 
     _ENERGY_PATH = "technique/scan/energy"
 
-    _DATASET_NAME_PATH = "technique/scan/name"
+    _DATASET_NAME_PATH = ("technique/scan/name",)
 
-    _GRP_SIZE_PATH = "technique/scan/nb_scans"
+    _GRP_SIZE_PATH = ("technique/scan/nb_scans",)
 
-    _SAMPLE_NAME_PATH = "sample/name"
+    _SAMPLE_NAME_PATH = ("sample/name",)
 
-    _TITLE_PATH = "title"
+    _TITLE_PATH = ("title",)
 
-    _INSTRUMENT_NAME_PATH = "instrument/title"
+    _INSTRUMENT_NAME_PATH = ("instrument/title",)
 
     _FOV_PATH = "technique/scan/field_of_view"
 
-    _NB_LOOP_PATH = "technique/scan/nb_loop"
+    _NB_LOOP_PATH = ("technique/scan/nb_loop", "technique/proj/nb_loop")
 
-    _NB_TOMO_PATH = "technique/scan/nb_tomo"
+    _NB_TOMO_PATH = ("technique/scan/nb_tomo", "technique/proj/nb_tomo")
 
-    _TOMO_N_PATH = "technique/scan/tomo_n"
+    _NB_TURNS_PATH = ("technique/proj/nb_turns",)
 
-    _START_TIME_PATH = "start_time"
+    _TOMO_N_PATH = "technique/proj/tomo_n", "technique/scan/tomo_n"
 
-    _END_TIME_PATH = "end_time"
+    _START_TIME_PATH = ("start_time",)
+
+    _END_TIME_PATH = ("end_time",)
 
     _TECHNIQUE_MOTOR_PATH = "technique/scan/motor"
 
-    _SOURCE_NAME = "instrument/machine/name"
+    _SOURCE_NAME = ("instrument/machine/name",)
 
-    _SOURCE_TYPE = "instrument/machine/type"
+    _SOURCE_TYPE = ("instrument/machine/type",)
+
+    _FRAME_FLIP_PATH = "technique/detector/flipping"
 
     def __init__(
         self,
@@ -183,10 +187,9 @@ class BaseAcquisition:
                         _logger.info("remove " + en_output_file)
                         os.remove(en_output_file)
                     elif _ask_for_file_removal(en_output_file) is False:
-                        _logger.info(
+                        raise OSError(
                             "unable to overwrite {}, exit".format(en_output_file)
                         )
-                        exit(0)
                     else:
                         os.remove(en_output_file)
             return en_output_file, entry
@@ -395,8 +398,7 @@ class BaseAcquisition:
             return node.attrs["units"]
         else:
             _logger.info(
-                "no unit found for %s, take default unit: %s"
-                "" % (node.name, default_unit)
+                f"no unit found for {node.name}, take default unit: {default_unit}"
             )
             return default_unit
 
@@ -410,7 +412,29 @@ class BaseAcquisition:
     def _get_positioners_node(entry_node):
         if not isinstance(entry_node, h5py.Group):
             raise TypeError("entry_node is expected to be a h5py.Group")
-        return BaseAcquisition._get_instrument_node(entry_node)["positioners"]
+        parent_node = BaseAcquisition._get_instrument_node(entry_node)
+        if "positioners" in parent_node:
+            return parent_node["positioners"]
+        else:
+            return None
+
+    @staticmethod
+    def _get_measurement_node(entry_node):
+        if not isinstance(entry_node, h5py.Group):
+            raise TypeError("entry_node is expected to be a h5py.Group")
+        if "measurement" in entry_node:
+            return entry_node["measurement"]
+        else:
+            return None
+
+    @staticmethod
+    def _get_machine_node(entry_node):
+        if not isinstance(entry_node, h5py.Group):
+            raise TypeError("entry_node is expected to be a h5py.Group")
+        if "instrument/machine" in entry_node:
+            return entry_node["instrument/machine"]
+        else:
+            return None
 
     def _read_rotation_motor_name(self) -> typing.Union[str, None]:
         """read rotation motor from root_url/technique/scan/motor
@@ -443,6 +467,49 @@ class BaseAcquisition:
                     )
                     return None
 
+    def _get_electric_current(self, root_node) -> list:
+        """retrieve electric current provide a time stamp for each of them"""
+        if root_node is None:
+            _logger.warning("no root url. Unable to read electric current")
+            return None, None
+        else:
+            grps = [
+                root_node,
+            ]
+
+            measurement_node = self._get_measurement_node(root_node)
+            if measurement_node is not None:
+                grps.append(measurement_node)
+            machine_node = self._get_machine_node(root_node)
+            if machine_node is not None:
+                grps.append(machine_node)
+
+            for grp in grps:
+                try:
+                    elec_current, unit = self._get_node_values_for_frame_array(
+                        node=grp,
+                        keys=self.configuration.machine_electric_current_keys,
+                        info_retrieve="machine electric current",
+                        expected_unit="mA",
+                        n_frame=None,
+                    )
+                except (ValueError, KeyError):
+                    pass
+                else:
+                    # handle case where elec_current is a scalar. Cast it to list before return
+                    if isinstance(elec_current, numpy.number):
+                        elec_current = [
+                            elec_current,
+                        ]
+
+                    return elec_current, unit
+            else:
+                _logger.warning(
+                    f"Unable to retrieve machine electric current for {root_node.name}"
+                )
+
+            return None, None
+
     def _get_rotation_angle(self, root_node, n_frame) -> tuple:
         """return the list of rotation angle for each frame"""
         if not isinstance(root_node, h5py.Group):
@@ -462,7 +529,7 @@ class BaseAcquisition:
             else:
                 return angles, unit
 
-        mess = "Unable to find rotation angle for {}" "".format(self.root_url.path())
+        mess = f"Unable to find rotation angle for {root_node.name}"
         if self.raise_error_if_issue:
             raise ValueError(mess)
         else:
@@ -490,7 +557,7 @@ class BaseAcquisition:
             else:
                 return x_tr, "m"
 
-        mess = "Unable to find x translation for {}" "".format(self.root_url.path())
+        mess = f"Unable to find x translation for {self.root_url.path()}"
         if self.raise_error_if_issue:
             raise ValueError(mess)
         else:
@@ -518,7 +585,7 @@ class BaseAcquisition:
             else:
                 return y_tr, "m"
 
-        mess = "Unable to find y translation for {}" "".format(self.root_url.path())
+        mess = f"Unable to find y translation for {self.root_url.path()}"
         if self.raise_error_if_issue:
             raise ValueError(mess)
         else:
@@ -546,7 +613,7 @@ class BaseAcquisition:
             else:
                 return z_tr, "m"
 
-        mess = "Unable to find z translation on node {}" "".format(root_node.name)
+        mess = f"Unable to find z translation on node {root_node.name}"
         if configuration.raises_error:
             raise ValueError(mess)
         else:
@@ -578,9 +645,7 @@ class BaseAcquisition:
             else:
                 return expo, unit
 
-        mess = "Unable to find frame exposure time on entry {}" "".format(
-            self.root_url.path()
-        )
+        mess = f"Unable to find frame exposure time on entry {self.root_url.path()}"
         if self.raise_error_if_issue:
             raise ValueError(mess)
         else:
@@ -604,9 +669,7 @@ class BaseAcquisition:
                 pass
             else:
                 return values, None
-        mess = "Unable to find {} on entry {}".format(
-            resource_name, self.root_url.path()
-        )
+        mess = f"Unable to find {resource_name} on entry {self.root_url.path()}"
         if self.raise_error_if_issue:
             raise ValueError(mess)
         else:
