@@ -48,7 +48,6 @@ from .acquisition.zseriesacquisition import is_z_series_frm_z_translation
 from .acquisition.xrdctacquisition import XRDCTAcquisition
 from .acquisition.xrd3dacquisition import XRD3DAcquisition
 from nxtomomill.utils import Format
-from silx.utils.deprecation import deprecated
 from nxtomomill.io.config import TomoHDF5Config
 from nxtomomill.io.framegroup import FrameGroup
 from nxtomomill.converter.baseconverter import BaseConverter
@@ -56,7 +55,6 @@ from nxtomomill.converter.hdf5.acquisition.baseacquisition import _ask_for_file_
 from silx.io.url import DataUrl
 from tomoscan.io import HDF5File
 from typing import Union
-from typing import Iterable
 import logging
 from nxtomomill.plugins import (
     get_plugins_instances_frm_env_var,
@@ -93,6 +91,8 @@ H5_FLAT_TITLES = Tomo.H5.FLAT_TITLES
 H5_REF_TITLES = H5_FLAT_TITLES
 H5_Y_ROT_KEY = Tomo.H5.Y_ROT_KEY
 H5_DIODE_KEYS = Tomo.H5.DIODE_KEYS
+H5_MAGNIFICATION_KEYS = Tomo.H5.MAGNIFICATION_KEYS
+
 
 DEFAULT_SCAN_TITLES = H5ScanTitles(
     H5_INIT_TITLES,
@@ -116,6 +116,7 @@ DEFAULT_H5_KEYS = H5FileKeys(
     H5_X_PIXEL_SIZE,
     H5_Y_PIXEL_SIZE,
     H5_DIODE_KEYS,
+    H5_MAGNIFICATION_KEYS,
 )
 
 
@@ -390,7 +391,12 @@ class _H5ToNxConverter(BaseConverter):
 
             def sort_fct(node):
                 node_to_treat = h5d.get(node, getlink=True)
-                if isinstance(node_to_treat, (h5py.ExternalLink, h5py.SoftLink)):
+                is_rearranged = h5d.get(node).attrs.get("is_rearranged", False)
+                # in some case the user might want to keep the order of the original sequence.
+                # in this case we expect some preprocessing to be done and which has tag the node with the 'is_rearranged' attribute
+                if not is_rearranged and isinstance(
+                    node_to_treat, (h5py.ExternalLink, h5py.SoftLink)
+                ):
                     return float(node_to_treat.path.split("/")[-1])
                 return float(node)
 
@@ -660,8 +666,7 @@ class _H5ToNxConverter(BaseConverter):
                     raise e
                 else:
                     _logger.error(
-                        "Fails to write %s. Error is %s"
-                        % (str(acquisition.root_url), str(e))
+                        f"Fails to write {str(acquisition.root_url)}. Error is {str(e)}"
                     )
             else:
                 res.extend(new_entries)
@@ -670,7 +675,7 @@ class _H5ToNxConverter(BaseConverter):
 
         # if we created one file per entry then create a master file with link to those entries
         if self.configuration.single_file is False and divide_into_sub_files:
-            _logger.info("create link in %s" % self.configuration.output_file)
+            _logger.info(f"create link in {self.configuration.output_file}")
             for (en_output_file, entry) in res:
                 with HDF5File(self.configuration.output_file, "a") as master_file:
                     link_file = os.path.relpath(
@@ -684,6 +689,8 @@ class _H5ToNxConverter(BaseConverter):
     def _check_conversion_is_possible(self):
         """Insure minimalistic information are provided"""
         if self.configuration.is_using_titles:
+            if self.configuration.input_file is None:
+                raise ValueError("input file should be provided")
             if not os.path.isfile(self.configuration.input_file):
                 raise ValueError(
                     "Given input file does not exists: {}"
@@ -705,13 +712,11 @@ class _H5ToNxConverter(BaseConverter):
                 _logger.info("remove {}".format(output_file))
                 os.remove(output_file)
             elif not _ask_for_file_removal(output_file):
-                _logger.info("unable to overwrite {}, exit".format(output_file))
-                exit(0)
+                raise OSError("unable to overwrite {}, exit".format(output_file))
             else:
                 os.remove(output_file)
         if not os.access(dir_name, os.W_OK):
-            _logger.error("You don't have rights to write on {}" "".format(dir_name))
-            exit(0)
+            raise OSError("You don't have rights to write on {}" "".format(dir_name))
 
     def _convert_entries_and_sub_entries_to_urls(self):
         if self.configuration.entries is not None:
@@ -781,69 +786,6 @@ class _H5ToNxConverter(BaseConverter):
         return tuple([_H5ToNxConverter._upgarde_url(url, input_file) for url in urls])
 
 
-@deprecated(replacement="from_h5_to_nx", since_version="0.5.0")
-def h5_to_nx(
-    input_file_path: str,
-    output_file: str,
-    single_file: bool,
-    file_extension: Union[str, None],
-    ask_before_overwrite: bool = True,
-    request_input: bool = False,
-    entries: Union[Iterable, None] = None,
-    ignore_sub_entries: Union[Iterable, None] = None,
-    input_callback=None,
-    file_keys=DEFAULT_H5_KEYS,
-    scan_titles=DEFAULT_SCAN_TITLES,
-    param_already_defined: Union[dict, None] = None,
-    is_xrdc_ct: Union[bool, None] = None,
-    progress=None,
-    raise_error_if_issue=False,
-    detector_sel_callback=None,
-):
-    configuration = TomoHDF5Config()
-    configuration.input_file = input_file_path
-    configuration.output_file = output_file
-    configuration.single_file = single_file
-    configuration.file_extension = file_extension
-    configuration.overwrite = ask_before_overwrite
-    configuration.request_input = request_input
-    configuration.entries = entries
-    configuration.raises_error = raise_error_if_issue
-    configuration.sub_entries_to_ignore = ignore_sub_entries
-    if param_already_defined is not None:
-        configuration.param_already_defined = param_already_defined
-    if is_xrdc_ct is True:
-        configuration.format = "xrd-ct"
-    elif is_xrdc_ct is False:
-        configuration.format = "standard"
-    # handle file keys
-    configuration.x_trans_keys = file_keys.x_trans_keys
-    configuration.y_trans_keys = file_keys.y_trans_keys
-    configuration.z_trans_keys = file_keys.z_trans_keys
-    configuration.exposition_time_keys = file_keys.acq_expo_time_keys
-    configuration.rotation_angle_keys = file_keys.rot_angle_keys
-    configuration.valid_camera_names = file_keys.valid_camera_names
-    configuration.y_rot_key = file_keys.y_rot_key
-    configuration.x_pixel_size_paths = file_keys.x_pixel_size
-    configuration.y_pixel_size_paths = file_keys.y_pixel_size
-    configuration.diode_keys = file_keys.diode_keys
-    # handle titles keys
-    configuration.init_titles = scan_titles.init_titles
-    configuration.zserie_init_titles = scan_titles.init_zserie_titles
-    configuration.pcotomo_init_titles = scan_titles.init_pcotomo_titles
-    configuration.dark_titles = scan_titles.dark_titles
-    configuration.flat_titles = scan_titles.flat_titles
-    configuration.projections_titles = scan_titles.proj_titles
-    configuration.alignment_titles = scan_titles.align_titles
-
-    return from_h5_to_nx(
-        configuration=configuration,
-        input_callback=input_callback,
-        progress=progress,
-        detector_sel_callback=detector_sel_callback,
-    )
-
-
 def from_h5_to_nx(
     configuration: TomoHDF5Config,
     input_callback=None,
@@ -880,7 +822,7 @@ def get_bliss_tomo_entries(input_file_path: str, configuration: TomoHDF5Config):
         acquisitions = []
 
         for group_name in h5d.keys():
-            _logger.debug("parse %s" % group_name)
+            _logger.debug(f"parse {group_name}")
             entry = h5d[group_name]
             # improve handling of External (this is the case of proposal files)
             if isinstance(h5d.get(group_name, getlink=True), h5py.ExternalLink):
