@@ -61,7 +61,7 @@ class Tomo:
         Y_TRANS_KEYS = ("sy", "d3ty", "hry", "py")
         """Keys used by bliss to store y translation"""
 
-        Z_TRANS_KEYS = ("sz", "d3tz", "hrz", "pz")
+        Z_TRANS_KEYS = ("sz", "d3tz", "hrz", "pz", "mrsz")
         """Keys used by bliss to store translation"""
 
         Y_ROT_KEY = "instrument/positioners/yrot"
@@ -80,6 +80,7 @@ class Tomo:
             "sequence_of_scans",
             "tomo:halfturn",
             "tomo:multiturn",
+            "tomo:helical",
         )
         """if a scan starts by one of those string then is considered as
         initialization scan"""
@@ -87,7 +88,7 @@ class Tomo:
         ZSERIE_INIT_TITLES = ("tomo:zseries",)
         """specific titles for zserie. Will extend DEFAULT_SCAN_TITLES"""
 
-        PCOTOMO_INIT_TITLES = ("tomo:pcotomo",)
+        PCOTOMO_INIT_TITLES = ("tomo:pcotomo", "pcotomo:")
         """specific titles for pcotomo. Will extend DEFAULT_SCAN_TITLES"""
 
         DARK_TITLES = ("dark images", "dark")
@@ -104,7 +105,6 @@ class Tomo:
         alignment scan"""
 
         X_PIXEL_SIZE = (
-            "technique/optic/sample_pixel_size ",
             "technique/optic/sample_pixel_size",
             "technique/detector/pixel_size",
             "hry_step_size",
@@ -113,29 +113,38 @@ class Tomo:
         # warning: we can have two cases: one with an empty space at the end or not
 
         Y_PIXEL_SIZE = (
-            "technique/optic/sample_pixel_size ",
             "technique/optic/sample_pixel_size",
             "technique/detector/pixel_size",
             "hry_step_size",
         )
 
+        MAGNIFICATION_KEYS = ("technique/optic/magnification",)
+
         DISTANCE_KEYS = ("technique/scan/sample_detector_distance",)
         """keys used by bliss to store the sample to detector distance"""
 
+        MACHINE_ELECTRIC_CURRENT_KEYS = ("current",)
+        """keys used by bliss to store the electric current"""
+
     class EDF:
         """EDF settings for tomography"""
 
-        MOTOR_POS = "motor_pos"
+        MOTOR_POS = ("motor_pos",)
 
-        MOTOR_MNE = "motor_mne"
+        MOTOR_MNE = ("motor_mne",)
 
-        ROT_ANGLE = "srot"
+        ROT_ANGLE = (
+            "srot",
+            "somega",
+        )
 
-        X_TRANS = "sx"
+        X_TRANS = ("sx",)
 
-        Y_TRANS = "sy"
+        Y_TRANS = ("sy",)
 
-        Z_TRANS = "sz"
+        Z_TRANS = ("sz",)
+
+        MACHINE_ELECTRIC_CURRENT = ("srcur", "srcurrent")
 
         # EDF_TO_IGNORE = ['HST', '_slice_']
         TO_IGNORE = ("_slice_",)
